@@ -37,7 +37,7 @@
 extern "C" {
 #endif
 
-#define LIBGNUTLS_VERSION "0.9.99"
+#define LIBGNUTLS_VERSION "1.0.0"
 
 #ifndef HAVE_SIZE_T
 # define HAVE_SIZE_T
@@ -409,6 +409,7 @@ void gnutls_global_set_mem_functions(
 extern gnutls_alloc_function gnutls_malloc;
 extern gnutls_calloc_function gnutls_calloc;
 extern gnutls_free_function gnutls_free;
+extern char* (*gnutls_strdup)( const char*);
 
 typedef void (*gnutls_log_func)( int, const char*);
 void gnutls_global_set_log_function( gnutls_log_func log_func);
@@ -641,7 +642,6 @@ int gnutls_pem_base64_decode_alloc( const char* header, const gnutls_datum *b64_
 
 #define GNUTLS_E_ILLEGAL_SRP_USERNAME -90
 #define GNUTLS_E_SRP_PWD_PARSING_ERROR -91
-#define GNUTLS_E_EMPTY_SRP_USERNAME -92
 #define GNUTLS_E_NO_TEMPORARY_DH_PARAMS -93
 
 /* For certificate and key stuff
