@@ -93,7 +93,7 @@ void gnutls_x509_crq_deinit(gnutls_x509_crq crq)
   * @format: One of DER or PEM
   *
   * This function will convert the given DER or PEM encoded Certificate
-  * to the native gnutls_x509_crq format. The output will be stored in 'cert'.
+  * to the native gnutls_x509_crq format. The output will be stored in @cert.
   *
   * If the Certificate is PEM encoded it should have a header of "NEW CERTIFICATE REQUEST".
   *
@@ -161,12 +161,13 @@ int gnutls_x509_crq_import(gnutls_x509_crq crq, const gnutls_datum * data,
   * gnutls_x509_crq_get_dn - This function returns the Certificate request subject's distinguished name
   * @crq: should contain a gnutls_x509_crq structure
   * @buf: a pointer to a structure to hold the name (may be null)
-  * @sizeof_buf: initialy holds the size of 'buf'
+  * @sizeof_buf: initialy holds the size of @buf
   *
   * This function will copy the name of the Certificate request subject in the provided buffer. The name 
-  * will be in the form "C=xxxx,O=yyyy,CN=zzzz" as described in RFC2253.
+  * will be in the form "C=xxxx,O=yyyy,CN=zzzz" as described in RFC2253. The output
+  * string will be ASCII or UTF-8 encoded, depending on the certificate data.
   *
-  * If buf is null then only the size will be filled.
+  * If @buf is null then only the size will be filled.
   *
   * Returns GNUTLS_E_SHORT_MEMORY_BUFFER if the provided buffer is not long enough, and
   * in that case the sizeof_buf will be updated with the required size.
@@ -192,17 +193,18 @@ int gnutls_x509_crq_get_dn(gnutls_x509_crq crq, char *buf,
   * @indx: In case multiple same OIDs exist in the RDN, this specifies which to send. Use zero to get the first one.
   * @raw_flag: If non zero returns the raw DER data of the DN part.
   * @buf: a pointer to a structure to hold the name (may be null)
-  * @sizeof_buf: initialy holds the size of 'buf'
+  * @sizeof_buf: initialy holds the size of @buf
   *
   * This function will extract the part of the name of the Certificate request subject, specified
-  * by the given OID. The output will be encoded as described in RFC2253.
+  * by the given OID. The output will be encoded as described in RFC2253. The output
+  * string will be ASCII or UTF-8 encoded, depending on the certificate data.
   *
   * Some helper macros with popular OIDs can be found in gnutls/x509.h
   * If raw flag is zero, this function will only return known OIDs as text. Other OIDs
   * will be DER encoded, as described in RFC2253 -- in hex format with a '\#' prefix.
   * You can check about known OIDs using gnutls_x509_dn_oid_known().
   *
-  * If buf is null then only the size will be filled.
+  * If @buf is null then only the size will be filled.
   *
   * Returns GNUTLS_E_SHORT_MEMORY_BUFFER if the provided buffer is not long enough, and
   * in that case the sizeof_buf will be updated with the required size.
@@ -226,7 +228,7 @@ int gnutls_x509_crq_get_dn_by_oid(gnutls_x509_crq crq, const char* oid,
   * @crq: should contain a gnutls_x509_crq structure
   * @indx: Specifies which DN OID to send. Use zero to get the first one.
   * @oid: a pointer to a structure to hold the name (may be null)
-  * @sizeof_oid: initialy holds the size of 'oid'
+  * @sizeof_oid: initialy holds the size of @oid
   *
   * This function will extract the requested OID of the name of the Certificate request subject, specified
   * by the given index. 
@@ -419,10 +421,10 @@ int gnutls_x509_crq_get_challenge_password(gnutls_x509_crq crq,
   * @oid: holds an Object Identifier in a null terminated string
   * @raw_flag: must be 0, or 1 if the data are DER encoded
   * @data: a pointer to the input data
-  * @sizeof_data: holds the size of 'data'
+  * @sizeof_data: holds the size of @data
   *
   * This function will set the part of the name of the Certificate request subject, specified
-  * by the given OID. 
+  * by the given OID. The input string should be ASCII or UTF-8 encoded.
   *
   * Some helper macros with popular OIDs can be found in gnutls/x509.h
   * With this function you can only set the known OIDs. You can test
@@ -447,10 +449,10 @@ int gnutls_x509_crq_set_dn_by_oid(gnutls_x509_crq crq, const char* oid,
 /**
   * gnutls_x509_crq_set_version - This function will set the Certificate request version
   * @crq: should contain a gnutls_x509_crq structure
-  * @version: holds the version number. For v1 Requests must be 0.
+  * @version: holds the version number. For v1 Requests must be 1.
   *
-  * This function will set the version of the certificate request. This
-  * must be zero.
+  * This function will set the version of the certificate request. For
+  * version 1 requests this must be one.
   *
   * Returns 0 on success.
   *
@@ -458,13 +460,16 @@ int gnutls_x509_crq_set_dn_by_oid(gnutls_x509_crq crq, const char* oid,
 int gnutls_x509_crq_set_version(gnutls_x509_crq crq, unsigned int version)
 {
 int result;
-uint8 null = version;
+char null = version;
 
 	if (crq==NULL) {
 		gnutls_assert();
 		return GNUTLS_E_INVALID_REQUEST;
 	}
 
+	null -= 1;
+	if (null < 0) null = 0;
+	
 	result = asn1_write_value( crq->crq, "certificationRequestInfo.version", &null, 1);
 	if (result != ASN1_SUCCESS) {
 		gnutls_assert();
@@ -474,6 +479,37 @@ uint8 null = version;
 	return 0;
 }
 
+/**
+  * gnutls_x509_crq_get_version - This function returns the Certificate request's version number
+  * @crq: should contain a gnutls_x509_crq structure
+  *
+  * This function will return the version of the specified Certificate request.
+  *
+  * Returns a negative value on error.
+  *
+  **/
+int gnutls_x509_crq_get_version(gnutls_x509_crq crq)
+{
+	opaque version[5];
+	int len, result;
+
+	if (crq==NULL) {
+		gnutls_assert();
+		return GNUTLS_E_INVALID_REQUEST;
+	}
+
+	len = sizeof(version);
+	if ((result = asn1_read_value(crq->crq, "certificationRequestInfo.version", version, &len)) !=
+		ASN1_SUCCESS) {
+		
+		if (result == ASN1_ELEMENT_NOT_FOUND) return 1; /* the DEFAULT version */
+		gnutls_assert();
+		return _gnutls_asn2err(result);
+	}
+
+	return (int) version[0] + 1;
+}
+
 /**
   * gnutls_x509_crq_set_key - This function will associate the Certificate request with a key
   * @crq: should contain a gnutls_x509_crq structure
