@@ -136,17 +136,26 @@ static const char* read_pass( const char* input_str)
 {
 #ifdef _WIN32
 static char input[128];
+#endif
+const char* pass;
+
+	if (info.pass) return info.pass;
+
+#ifdef _WIN32
 
 	fputs( input_str, stderr);
 	fgets( input, sizeof(input), stdin);
 	
 	input[strlen(input)-1] = 0;
 
-	if (strlen(input)==0) return NULL;
+	if (strlen(input)==0 || input[0]=='\n') return NULL;
 
 	return input;
 #else
-	return getpass(input_str);
+	pass = getpass(input_str);
+	if (pass == NULL || strlen(pass)==0 || pass[0]=='\n') return NULL;
+
+	return pass;
 #endif
 }
 
@@ -184,7 +193,7 @@ int ret;
 		fprintf(stderr, "privkey_generate: %s\n", gnutls_strerror(ret));
 		exit(1);
 	}
-	
+
 	return key;
 
 }
@@ -227,13 +236,14 @@ size_t size;
 		}
 	} else {
 		unsigned int flags;
+		const char* pass;
 		
 		if (info.export) flags = GNUTLS_PKCS_USE_PKCS12_RC2_40;
 		else flags = GNUTLS_PKCS_USE_PKCS12_3DES;
-		if (info.pass == NULL) flags = GNUTLS_PKCS_PLAIN;
+		if ((pass=read_pass("Enter password: ")) == NULL) flags = GNUTLS_PKCS_PLAIN;
 
 		size = sizeof(buffer);
-		ret = gnutls_x509_privkey_export_pkcs8( key, out_cert_format, info.pass, flags, buffer, &size);
+		ret = gnutls_x509_privkey_export_pkcs8( key, out_cert_format, pass, flags, buffer, &size);
 		if (ret < 0) {
 			fprintf(stderr, "privkey_export_pkcs8: %s\n", gnutls_strerror(ret));
 			exit(1);
@@ -264,6 +274,8 @@ gnutls_x509_crt generate_certificate( gnutls_x509_privkey *ret_key)
 	int size, serial;
 	int days, result, ca_status;
 	const char* str;
+	int vers = 3; /* the default version in the certificate 
+	               */
 	gnutls_x509_crq crq; /* request */
 
 	size = gnutls_x509_crt_init(&crt);
@@ -306,11 +318,6 @@ gnutls_x509_crt generate_certificate( gnutls_x509_privkey *ret_key)
 		}
 	}
 
-	result = gnutls_x509_crt_set_version( crt, 2);
-	if (result < 0) {
-		fprintf(stderr, "set_version: %s\n", gnutls_strerror(result));
-		exit(1);
-	}
 
 	serial = read_int( "Enter the certificate's serial number (decimal): ");
 	buffer[2] = serial & 0xff;
@@ -326,7 +333,7 @@ gnutls_x509_crt generate_certificate( gnutls_x509_privkey *ret_key)
 
 	fprintf(stderr, "\n\nActivation/Expiration time.\n");	
 	gnutls_x509_crt_set_activation_time( crt, time(NULL));
-	
+
 	do {
 		days = read_int( "The generated certificate will expire in (days): ");
 	} while( days==0);
@@ -371,6 +378,12 @@ gnutls_x509_crt generate_certificate( gnutls_x509_privkey *ret_key)
 		}
 	}
 
+	result = gnutls_x509_crt_set_version( crt, vers);
+	if (result < 0) {
+		fprintf(stderr, "set_version: %s\n", gnutls_strerror(result));
+		exit(1);
+	}
+
 	*ret_key = key;
 	return crt;
 
@@ -628,7 +641,8 @@ static inline int known_oid( const char* oid)
 void certificate_info( void)
 {
 	gnutls_x509_crt crt;
-	int ret, i, indx, j;
+	int ret;
+	unsigned int i, indx, j;
 	unsigned int critical, key_usage;
 	time_t tim;
 	gnutls_datum pem;
@@ -789,7 +803,7 @@ void certificate_info( void)
 				indx = 0;
 			}
 
-			fprintf( outfile, "\n\t%s: ", oid);
+			fprintf( outfile, "\t%s: ", oid);
 			
 			size = sizeof(buffer);
 			ret = gnutls_x509_crt_get_extension_by_oid( crt, oid, indx, buffer, &size, &critical);
@@ -801,8 +815,8 @@ void certificate_info( void)
 
 				print = printable;
 				for (j = 0; j < size; j++) {
-					sprintf(print, "%.2x ", (unsigned char) buffer[j]);
-					print += 3;
+					sprintf(print, "%.2x", (unsigned char) buffer[j]);
+					print += 2;
 				}
 				fprintf(outfile, "\t\tDER Data: %s\n", printable);
 			
@@ -851,7 +865,8 @@ void certificate_info( void)
 
 static void print_certificate_info( gnutls_x509_crt crt)
 {
-	int ret, i;
+	int ret;
+	unsigned int i;
 	unsigned int critical, key_usage;
 	time_t tim;
 	char serial[40];
@@ -970,16 +985,16 @@ static void print_certificate_info( gnutls_x509_crt crt)
 void crl_info(void)
 {
 	gnutls_x509_crl crl;
-	int ret, i, rc;
+	int ret, rc;
 	size_t size;
 	time_t tim;
+	unsigned int i;
 	gnutls_datum pem;
 	unsigned char serial[40];
 	size_t serial_size = sizeof(serial), dn_size;
 	char printable[256];
-	char *print;
+	char *print, dn[256];
 	const char* cprint;
-	char dn[256];
 		
 	size = fread( buffer, 1, sizeof(buffer)-1, infile);
 	buffer[size] = 0;
@@ -1029,7 +1044,7 @@ void crl_info(void)
 	rc = gnutls_x509_crl_get_crt_count( crl);
 	fprintf(outfile, "Revoked certificates: %d\n", rc);
 
-	for (i=0;i<rc;i++) {
+	for (i=0;i<(unsigned int)rc;i++) {
 		/* serial number
 		 */
 		serial_size = sizeof(serial);
@@ -1051,11 +1066,13 @@ void privkey_info( void)
 {
 	gnutls_x509_privkey key;
 	size_t size;
-	int ret, i;
+	int ret;
+	unsigned int i;
 	gnutls_datum pem;
 	char printable[256];
 	char *print;
 	const char* cprint;
+	const char* pass;
 		
 	size = fread( buffer, 1, sizeof(buffer)-1, infile);
 	buffer[size] = 0;
@@ -1065,10 +1082,12 @@ void privkey_info( void)
 	pem.data = buffer;
 	pem.size = size;
 	
+	pass = read_pass("Enter password: ");
+
 	if (!info.pkcs8) {
 		ret = gnutls_x509_privkey_import(key, &pem, in_cert_format);
 	} else {
-		ret = gnutls_x509_privkey_import_pkcs8(key, &pem, in_cert_format, info.pass, 0);
+		ret = gnutls_x509_privkey_import_pkcs8(key, &pem, in_cert_format, pass, 0);
 	}
 
 	if (ret < 0) {
@@ -1113,6 +1132,7 @@ gnutls_x509_privkey key;
 int ret;
 gnutls_datum dat;
 size_t size;
+const char* pass;
 
 	if (!info.privkey && !mand) return NULL;
 
@@ -1140,12 +1160,14 @@ size_t size;
 	
 	dat.data = buffer;
 	dat.size = size;
-	
+		
 	if (!info.pkcs8)
 		ret = gnutls_x509_privkey_import( key, &dat, in_cert_format);
-	else
+	else {
+		pass = read_pass("Enter password: ");
 		ret = gnutls_x509_privkey_import_pkcs8( key, &dat, in_cert_format,
-			info.pass, 0);
+			pass, 0);
+	}
 	
 	if (ret < 0) {
 		fprintf(stderr, "privkey_import: %s\n", gnutls_strerror(ret));
@@ -1200,6 +1222,7 @@ gnutls_x509_privkey load_ca_private_key()
 FILE* fd;
 gnutls_x509_privkey key;
 int ret;
+const char* pass;
 gnutls_datum dat;
 size_t size;
 
@@ -1232,9 +1255,11 @@ size_t size;
 	
 	if (!info.pkcs8)
 		ret = gnutls_x509_privkey_import( key, &dat, in_cert_format);
-	else
+	else {
+		pass = read_pass("Enter password: ");
 		ret = gnutls_x509_privkey_import_pkcs8( key, &dat, in_cert_format,
-			info.pass, 0);
+			pass, 0);
+	}
 	
 	if (ret < 0) {
 		fprintf(stderr, "privkey_import: %s\n", gnutls_strerror(ret));
@@ -1369,7 +1394,7 @@ void generate_request(void)
 	read_crq_set( crq, "State or province name: ", GNUTLS_OID_X520_LOCALITY_NAME);
 	read_crq_set( crq, "Common name: ", GNUTLS_OID_X520_COMMON_NAME);
 
-	ret = gnutls_x509_crq_set_version( crq, 0);
+	ret = gnutls_x509_crq_set_version( crq, 1);
 	if (ret < 0) {
 		fprintf(stderr, "set_version: %s\n", gnutls_strerror(ret));
 		exit(1);
@@ -1722,8 +1747,7 @@ void generate_pkcs12( void)
 		name = read_str("Enter a name for the key: ");
 	} while( name == NULL);
 
-	if (info.pass) password = info.pass;
-	else password = read_pass( "Enter password: ");
+	password = read_pass( "Enter password: ");
 
 	result = gnutls_pkcs12_bag_init( &bag);
 	if (result < 0) {
@@ -1956,8 +1980,7 @@ void pkcs12_info( void)
 	data.data = buffer;
 	data.size = size;
 
-	if (info.pass) password = info.pass;
-	else password = read_pass( "Enter password: ");
+	password = read_pass( "Enter password: ");
 	
 	result = gnutls_pkcs12_init(&pkcs12);
 	if (result < 0) {
